Coverage for C:\src\imod-python\imod\mf6\interfaces\ilinedatapackage.py: 79%

1 from abc import abstractmethod

2 from typing import TYPE_CHECKING

3

4 from imod.mf6.interfaces.ipackagebase import IPackageBase

5

6 if TYPE_CHECKING:

7 import geopandas as gpd

8

9

10 class ILineDataPackage(IPackageBase):

11 """

12 Interface for packages for which the data is defined by lines independent of the domain definition.

13 """

14

15 @property

16 @abstractmethod

17 def line_data(self) -> "gpd.GeoDataFrame":

18 raise NotImplementedError

19

20 @line_data.setter

21 @abstractmethod

22 def line_data(self, value: "gpd.GeoDataFrame") -> None:

23 raise NotImplementedError